package cn.com.ctop.track.service.impl;

import cn.com.ctop.track.entity.MaterialUploadTask;
import cn.com.ctop.track.entity.TaskVo;
import cn.com.ctop.track.mapper.MaterialUploadTaskMapper;
import cn.com.ctop.track.service.IMaterialUploadTaskService;
import cn.com.ctop.track.utils.Check;
import cn.com.ctop.track.utils.LoadFileUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.entity.mime.content.FileBody;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.FileSystemResource;
import org.springframework.stereotype.Service;

import java.io.File;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
 * 同步素材任务
 *
 * @author jeecg-boot
 * 2021-10-21
 * @version V1.0
 */
@Service
@Slf4j
public class MaterialUploadTaskServiceImpl extends ServiceImpl<MaterialUploadTaskMapper, MaterialUploadTask> implements IMaterialUploadTaskService {
    @Autowired
    private MaterialUploadTaskMapper materialUploadTaskMapper;
    // private static String downloadUrl = "/data/file/video/";
    private static String downloadUrl = "D:\\file";
    private static ExecutorService kuaishouTiaoExecutorService = Executors.newFixedThreadPool(5);

    @Override
    public void upload(String signature) {
        TaskVo taskVo = getTaskList(signature);
        if (Check.isNull(taskVo)) {
            log.info("此素材md5未获取到待上传的任务列表");
            return;
        }
        List<MaterialUploadTask> taskList = taskVo.getTaskList();
        if (Check.isNull(taskList)) {
            log.info("此素材md5未获取到待上传的任务列表");
            return;
        }
        MaterialUploadTask materialUploadTask = taskList.get(0);
        String materialUrl = materialUploadTask.getMaterialUrl();
        String localUrl = LoadFileUtil.downLoadFromUrl(materialUrl, downloadUrl);
        File file = new File(localUrl);
        FileSystemResource resource = null;
        Integer materialType = null;
        if (!Check.isNull(taskVo.getKuaiShou())) {
            resource = new FileSystemResource(file);

            JSONObject sizeJson = materialUploadTaskMapper.getVideoSize(signature);
            if (Check.isNull(sizeJson)) {
                Integer type = MaterialEnum.getTypeBySize(Integer.valueOf(materialParameter.getWidth()), Integer.valueOf(materialParameter.getHeight()));
                if (!Check.isNull(type) && type != 0) {
                    requestJson.put("type", type);
                }
            }

        }
        FileBody fileBody = null;
        if (!Check.isNull(taskVo.getBytedance())) {
            fileBody = new FileBody(file);
        }

        for (MaterialUploadTask task : taskList) {
            if (task.getMediaId() == 2 || task.getMediaId() == 4) {
                uploadKuaiShou(task, resource);

            } else if (task.getMediaId() == 1 || task.getMediaId() == 3) {

            }


        }


    }


    private void uploadKuaiShou(MaterialUploadTask task, FileSystemResource resource) {
        kuaishouTiaoExecutorService.submit(new Runnable() {
            @Override
            public void run() {
                try {
                    Long accountId = task.getAccountId();
                    if (Check.isNull(accountId)) {
                        log.error("账户不能为空");
                        return;
                    }
                    String token = materialUploadTaskMapper.getTokenByAccountId(accountId);
                    if (Check.isNull(token)) {
                        log.error("此账户id未获取到token,accountId:{}", accountId);
                        return;
                    }


                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });

    }


    private TaskVo getTaskList(String signature) {
        TaskVo taskVo = new TaskVo();
        QueryWrapper<MaterialUploadTask> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("signature", signature);
        queryWrapper.eq("task_status", 1);
        List<MaterialUploadTask> materialUploadTasks = materialUploadTaskMapper.selectList(queryWrapper);
        if (Check.isNull(materialUploadTasks)) {
            return null;
        }
        taskVo.setTaskList(materialUploadTasks);
        List<Integer> mediaList = materialUploadTaskMapper.getMediaList(signature);
        for (int i = 0; i < mediaList.size(); i++) {
            Integer mediaId = mediaList.get(i);
            if (mediaId == 2 || mediaId == 4) {
                taskVo.setKuaiShou(1);
            }
            if (mediaId == 1 || mediaId == 3) {
                taskVo.setBytedance(1);
            }
        }
        return taskVo;
    }


}
